@@ -168,9 +168,9 @@ TdeSudo::TdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 		kdeSycoca = TQFile::encodeName(locateLocal("cache", "tdesycoca"));
 	}
 
-	connect( p, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQT_SLOT(receivedOut(TDEProcess*, char*, int)) );
-	connect( p, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQT_SLOT(receivedOut(TDEProcess*, char*, int)) );
-	connect( p, TQT_SIGNAL(processExited (TDEProcess *)), this, TQT_SLOT(procExited(TDEProcess*)));
+	connect( p, TQ_SIGNAL(receivedStdout(TDEProcess*, char*, int)), this, TQ_SLOT(receivedOut(TDEProcess*, char*, int)) );
+	connect( p, TQ_SIGNAL(receivedStderr(TDEProcess*, char*, int)), this, TQ_SLOT(receivedOut(TDEProcess*, char*, int)) );
+	connect( p, TQ_SIGNAL(processExited (TDEProcess *)), this, TQ_SLOT(procExited(TDEProcess*)));
 
 	TQString xauthenv = TQString(getenv("HOME")) + "/.Xauthority";
 	p->setEnvironment("XAUTHORITY", xauthenv);
@@ -205,7 +205,7 @@ TdeSudo::TdeSudo(TQWidget *parent, const char *name,const TQString& icon, const
 		chmod(m_tmpname.ascii(),0644);
 	
 	QCStringList output;
-	while (fgets(buf, 1024, f) > 0)
+	while (fgets(buf, 1024, f) != NULL)
 		output += buf; 
 	if (pclose(f) < 0) {
 		kdError() << k_lineinfo << "Could not run xauth.\n";
