@@ -25,7 +25,7 @@
 #include <config.h>
 #endif
 
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tqwidget.h>
 #include <kpassdlg.h>
 #include <tqstring.h>
